# Sachin Test python package

## How to use this package
```python
from sachin.perceptron import Perceptron
model = Perceptron(eta=0.3, epochs=10)
```

## References - 

* [Official python docs for PYPI](https://packaging.python.org/tutorials/packaging-projects/)

* [Github action file for PYPI](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)


to get version-
````
pip list
````

### to initiate setup.py
````
pip install -e .
````

### to check

````
from sachin.perceptron import perceptron
````
